/**
 * @file element_count.hpp
 *
 * @copyright Copyright (C) 2013-2014  SDML (www.srcML.org)
 *
 * The srcML Toolkit is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * The srcML Toolkit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the srcML Toolkit; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

 /*

  Count each the occurrences of each srcML element.

  Input: input_file.xml
  Useage: element_count input_file.xml
  
  */

#include "element_count_handler.hpp"
#include <srcSAXController.hpp>

#include <map>
#include <iostream>

/**
 * main
 * @param argc number of arguments
 * @param argv the provided arguments (array of C strings)
 * 
 * Invoke srcSAX handler to count element occurences and print out the resulting element counts.
 */
int main(int argc, char * argv[]) {

  if(argc < 2) {

    std::cerr << "Useage: element_count input_file.xml\n";
    exit(1);

  }

  srcSAXController control(argv[1]);
  element_count_handler handler;
  control.parse(&handler);

  for(std::map<std::string, unsigned long long>::const_iterator citr = handler.get_counts().begin(); citr != handler.get_counts().end(); ++citr) {

  	std::cout << citr->first << ": " << citr->second << '\n';

  }

  return 0;
}
